@@ -1,5 +1,7 @@
-calculate.CV <- function(formula, data, offset = NULL, weights = NULL, kbin = 25, family = c("gaussian", "binomial", "poisson"), KfoldCV = 5) {
+calculate.CV <- function(formula, data, offset = NULL, weights = NULL, kernel = c("Gaussian", "Epanechnikov"), kbin = 25, family = c("gaussian", "binomial", "poisson"), KfoldCV = 5) {
   family <- match.arg(family)
+  kernel <- match.arg(kernel)
+
   n <- nrow(data)
   if(is.null(weights)) {
     weights <- rep(1, n)
@@ -21,7 +23,7 @@ calculate.CV <- function(formula, data, offset = NULL, weights = NULL, kbin = 25
     wtest <- weights[which(groups == x)]
     offtrain <- offset[-which(groups == x)]
     offtest <- offset[which(groups == x)]
-    mod <- sback.fit(formula = formula, data = train, offset = offtrain, weights = wtrain, kbin = kbin, family = family, newdata = test, newoffset = offtest, pred = TRUE)
+    mod <- sback.fit(formula = formula, data = train, offset = offtrain, weights = wtrain, kernel = kernel, kbin = kbin, family = family, newdata = test, newoffset = offtest, pred = TRUE)
     if(mod$fit$err == 0) {
       response <- as.character(attr(terms(formula), "variables")[2]) # Response variable
       ECM <- append(ECM, dev(test[,response], mod$pfitted.values, wtest, family = family))
